This package help user to read data from HKEX daily report. 
It is license based on GPLv3. 
Every trade-day, the Hong Kong Exchange (HKEx below) will release daily-report on derivatives. 
Include Hang Seng Index Futures and Options. 
This package want to transform those report data into other format (like JSON, Pandas, etc)
